@@ -202,6 +202,7 @@ main (int argc, char **argv)
   GdkRectangle rect;
   GError *error = NULL;
   char *font = NULL;
+  char **remaining = NULL;
   GtkApplication *application;
   guint status;
   GOptionEntry goptions[] =
@@ -210,6 +211,8 @@ main (int argc, char **argv)
       N_("Font to start with; ex: 'Serif 27'"), N_("FONT") },
     { "version", 0, G_OPTION_FLAG_HIDDEN | G_OPTION_FLAG_NO_ARG, 
       G_OPTION_ARG_CALLBACK, option_version_cb, NULL, NULL },
+    { G_OPTION_REMAINING, 0, 0, G_OPTION_ARG_STRING_ARRAY, &remaining,
+      NULL, N_("[STRING…]") },
     { NULL }
   };
 
@@ -217,10 +220,9 @@ main (int argc, char **argv)
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
 
-#ifdef HAVE_GCONF
-  /* GConf uses ORBit2 which need GThread. See bug #565516 */
-  g_thread_init (NULL);
-#endif
+  /* Not interested in silly debug spew polluting the journal, bug #749195 */
+  if (g_getenv ("G_ENABLE_DIAGNOSTIC") == NULL)
+    g_setenv ("G_ENABLE_DIAGNOSTIC", "0", TRUE);
 
   /* Set programme name explicitly (see bug #653115) */
   g_set_prgname("gucharmap");
